package com.cpms.project.process.domain;

import java.util.Date;
import com.fasterxml.jackson.annotation.JsonFormat;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.cpms.common.annotation.Excel;
import com.cpms.common.core.domain.BaseEntity;

/**
 * sis Record对象 t_sis_record
 * 
 * @author admin
 * @date 2024-05-22
 */
public class TSisRecord extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** id */
    private Long id;

    /** sis关联Id */
    @Excel(name = "sis关联Id")
    private Long sisId;

    /** 传感器位号 */
    @Excel(name = "传感器位号")
    private String sensorTag;

    /** 类型 */
    @Excel(name = "类型")
    private String type;

    /** 用途 */
    @Excel(name = "用途")
    private String service;

    /** 表决 */
    @Excel(name = "表决")
    private String votingQ;

    /** 联锁条件 */
    @Excel(name = "联锁条件")
    private String condition;

    /** 测试周期 */
    @Excel(name = "测试周期")
    private String mainPti;

    /** 最终元件位号 */
    @Excel(name = "最终元件位号")
    private String finalElementTag;

    /** h */
    @Excel(name = "h")
    private String h;

    /** 类型 */
    @Excel(name = "类型")
    private String hType;

    /** 用途 */
    @Excel(name = "用途")
    private String hService;

    /** 表决 */
    @Excel(name = "表决")
    private String votingH;

    /** 联锁动作 */
    @Excel(name = "联锁动作")
    private String action;

    /** 测试周期 */
    @Excel(name = "测试周期")
    private String mainPtiH;

    /** Filter */
    @Excel(name = "Filter")
    private String filter;

    /** 删除标识 */
    private Integer delFlag;

    /** 创建人 */
    @Excel(name = "创建人")
    private String createrCode;

    /** 创建日期 */
    @JsonFormat(pattern = "yyyy-MM-dd",timezone = "GMT+8")
    @Excel(name = "创建日期", width = 30, dateFormat = "yyyy-MM-dd")
    private Date createdate;

    /** 更新人 */
    @Excel(name = "更新人")
    private String updaterCode;

    /** 更新日期 */
    @JsonFormat(pattern = "yyyy-MM-dd",timezone = "GMT+8")
    @Excel(name = "更新日期", width = 30, dateFormat = "yyyy-MM-dd")
    private Date updatedate;

    /** 部门编号 */
    @Excel(name = "部门编号")
    private Long deptId;

    public void setId(Long id) 
    {
        this.id = id;
    }

    public Long getId() 
    {
        return id;
    }
    public void setSisId(Long sisId) 
    {
        this.sisId = sisId;
    }

    public Long getSisId() 
    {
        return sisId;
    }
    public void setSensorTag(String sensorTag) 
    {
        this.sensorTag = sensorTag;
    }

    public String getSensorTag() 
    {
        return sensorTag;
    }
    public void setType(String type) 
    {
        this.type = type;
    }

    public String getType() 
    {
        return type;
    }
    public void setService(String service) 
    {
        this.service = service;
    }

    public String getService() 
    {
        return service;
    }
    public void setVotingQ(String votingQ) 
    {
        this.votingQ = votingQ;
    }

    public String getVotingQ() 
    {
        return votingQ;
    }
    public void setCondition(String condition) 
    {
        this.condition = condition;
    }

    public String getCondition() 
    {
        return condition;
    }
    public void setMainPti(String mainPti) 
    {
        this.mainPti = mainPti;
    }

    public String getMainPti() 
    {
        return mainPti;
    }
    public void setFinalElementTag(String finalElementTag) 
    {
        this.finalElementTag = finalElementTag;
    }

    public String getFinalElementTag() 
    {
        return finalElementTag;
    }
    public void setVotingH(String votingH) 
    {
        this.votingH = votingH;
    }

    public String getVotingH() 
    {
        return votingH;
    }
    public void setAction(String action)
    {
        this.action = action;
    }

    public String getAction()
    {
        return action;
    }

    public String getMainPtiH() {
        return mainPtiH;
    }

    public void setMainPtiH(String mainPtiH) {
        this.mainPtiH = mainPtiH;
    }

    public void setFilter(String filter)
    {
        this.filter = filter;
    }

    public String getFilter() 
    {
        return filter;
    }
    public void setDelFlag(Integer delFlag) 
    {
        this.delFlag = delFlag;
    }

    public Integer getDelFlag() 
    {
        return delFlag;
    }
    public void setCreaterCode(String createrCode) 
    {
        this.createrCode = createrCode;
    }

    public String getCreaterCode() 
    {
        return createrCode;
    }
    public void setCreatedate(Date createdate) 
    {
        this.createdate = createdate;
    }

    public Date getCreatedate() 
    {
        return createdate;
    }
    public void setUpdaterCode(String updaterCode) 
    {
        this.updaterCode = updaterCode;
    }

    public String getUpdaterCode() 
    {
        return updaterCode;
    }
    public void setUpdatedate(Date updatedate) 
    {
        this.updatedate = updatedate;
    }

    public Date getUpdatedate() 
    {
        return updatedate;
    }
    public void setDeptId(Long deptId) 
    {
        this.deptId = deptId;
    }

    public Long getDeptId() 
    {
        return deptId;
    }

    public String getH() {
        return h;
    }

    public void setH(String h) {
        this.h = h;
    }

    public String gethType() {
        return hType;
    }

    public void sethType(String hType) {
        this.hType = hType;
    }

    public String gethService() {
        return hService;
    }

    public void sethService(String hService) {
        this.hService = hService;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this,ToStringStyle.MULTI_LINE_STYLE)
            .append("id", getId())
            .append("sisId", getSisId())
            .append("sensorTag", getSensorTag())
            .append("type", getType())
            .append("service", getService())
            .append("votingQ", getVotingQ())
            .append("condition", getCondition())
            .append("mainPti", getMainPti())
            .append("finalElementTag", getFinalElementTag())
            .append("votingH", getVotingH())
            .append("action", getAction())
            .append("filter", getFilter())
            .append("delFlag", getDelFlag())
            .append("createrCode", getCreaterCode())
            .append("createdate", getCreatedate())
            .append("updaterCode", getUpdaterCode())
            .append("updatedate", getUpdatedate())
            .append("deptId", getDeptId())
            .toString();
    }
}
